smartcard.reader.Reader.Reader

# ``smartcard`.`reader`.`Reader`.`Reader``

class documentation

`class Reader(object):`

Known subclasses: `smartcard.pcsc.PCSCReader.PCSCReader`, `smartcard.pyro.PyroReader.PyroReader`, `smartcard.pyro.server.RemoteReaderServer.RemoteReader`

View In Hierarchy

Reader abstract class.

The reader class is responsible for creating connections with a card.

Method | `__eq__` | Returns True if self==other (same name).
Method | `__hash__` | Returns a hash value for this object (self.name is unique).
Method | `__init__` | Constructs a new reader and store readername.
Method | `__repr__` | Returns card reader name string for `object` calls.
Method | `__str__` | Returns card reader name string for str(object) calls.
Method | `addtoreadergroup` | Add reader to a reader group.
Method | `createConnection` | Returns a card connection thru reader.
Method | `removefromreadergroup` | Remove reader from a reader group.
Instance Variable | `name` | Undocumented

def __eq__(self, other):

Returns True if self==other (same name).

def __hash__(self):

Returns a hash value for this object (self.name is unique).

def __init__(self, readername):
overridden in `smartcard.pcsc.PCSCReader.PCSCReader`, `smartcard.pyro.PyroReader.PyroReader`, `smartcard.pyro.server.RemoteReaderServer.RemoteReader`

Constructs a new reader and store readername.

def __repr__(self):

Returns card reader name string for `object` calls.

def __str__(self):

Returns card reader name string for str(object) calls.

def addtoreadergroup(self, groupname):
overridden in `smartcard.pcsc.PCSCReader.PCSCReader`, `smartcard.pyro.PyroReader.PyroReader`, `smartcard.pyro.server.RemoteReaderServer.RemoteReader`

Add reader to a reader group.

def createConnection(self):
overridden in `smartcard.pcsc.PCSCReader.PCSCReader`, `smartcard.pyro.PyroReader.PyroReader`, `smartcard.pyro.server.RemoteReaderServer.RemoteReader`

Returns a card connection thru reader.

def removefromreadergroup(self, groupname):
overridden in `smartcard.pcsc.PCSCReader.PCSCReader`, `smartcard.pyro.PyroReader.PyroReader`, `smartcard.pyro.server.RemoteReaderServer.RemoteReader`

Remove reader from a reader group.

name =
overridden in `smartcard.pyro.PyroReader.PyroReader`, `smartcard.pyro.server.RemoteReaderServer.RemoteReader`

Undocumented